#
# spec file for package ghc-base-orphans
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name base-orphans
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.9.2
Release:        1.2
Summary:        Backwards-compatible orphan instances for base
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
%endif

%description
'base-orphans' defines orphan instances that mimic instances available in later
versions of 'base' to a wider (older) range of compilers.
'base-orphans' does not export anything except the orphan instances themselves
and complements '<http://hackage.haskell.org/package/base-compat base-compat>'.

See the README for what instances are covered:
<https://github.com/haskell-compat/base-orphans#readme>. See also the
<https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not
covered> section.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.markdown README.markdown

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Apr 30 2024 Peter Simons <psimons@suse.com>
- Update base-orphans to version 0.9.2.
  [#]# Changes in 0.9.2 [2024.04.30]
  - Backport new instances from GHC 9.10/`base-4.20`:
  * `Fractional`, `RealFrac`, `Floating`, and `RealFloat` instances for `Compose`
* Wed Oct 11 2023 Peter Simons <psimons@suse.com>
- Update base-orphans to version 0.9.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/base-orphans-0.9.1/src/CHANGES.markdown
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Mar  8 2023 Peter Simons <psimons@suse.com>
- Update base-orphans to version 0.8.8.2.
  [#]# Changes in 0.8.8.2 [2023.03.07]
  - Fix GHC 9.2.1 build error that was accidentally introduced in
    `base-orphans-0.8.8`.
* Sun Mar  5 2023 Peter Simons <psimons@suse.com>
- Update base-orphans to version 0.8.8.1.
  [#]# Changes in 0.8.8.1 [2023.03.05]
  - Fix GHC 9.4 build error that was accidentally introduced in
    `base-orphans-0.8.8`.
  [#]# Changes in 0.8.8 [2023.03.05]
  - Backport new instances from GHC 9.6.1/`base-4.18.0.0`:
  * `Functor` instances for the `(,,,,) a b c d`, `(,,,,,) a b c d e`, and
    `(,,,,,) a b c d e f` tuple types.
  * `Eq` and `Ord` instances for `Generically`
* Thu Aug 11 2022 Peter Simons <psimons@suse.com>
- Update base-orphans to version 0.8.7.
  [#]# Changes in 0.8.7 [2022.08.11]
  - Backport new instances from GHC 9.2.2/`base-4.16.1.0`:
  * `Ix` instances for various integral types in `Foreign.C.Types`,
    `Foreign.Ptr`, and `System.Posix.Types`. For a complete list of such types,
    see https://gitlab.haskell.org/ghc/ghc/-/merge_requests/7385.
  - Backport a bugfix for the `Ord1 Down` instance from GHC 9.4/`base-4.17` such
    that it now uses reverse sort order.
* Mon Nov  1 2021 psimons@suse.com
- Update base-orphans to version 0.8.6.
  [#]# Changes in 0.8.6 [2021.10.29]
  - Backport `Eq`, `Ord`, `Bounded`, `Enum`, and `Ix` instances for `Solo`,
    introduced in GHC 9.2/`base-4.16`
  - Remove the backported `Eq1` and `Ord1` instances for `Fixed` that were
    introduced in `base-orphans-0.8.5`. While these briefly appeared in a
    release candidate version of GHC 9.2.1, they were ultimately removed from
    the final 9.2.1 release. This release of `base-orphans` synchronizes with
    that change.
* Thu Sep  2 2021 psimons@suse.com
- Update base-orphans to version 0.8.5.
  [#]# Changes in 0.8.5 [2021.08.29]
  - Backport new instances from GHC 9.2/`base-4.16`
  * `Eq1`, `Read1`, and `Show1` instances for `Complex`
  * `Eq1` and `Ord1` instances for `Fixed`
  * `Eq{1,2}`, `Ord{1,2}`, `Show{1,2}`, and `Read{1,2}` instances for `(,,)`
    and `(,,,)`
  * `Semigroup` and `Monoid` instances for `Data.Functor.Product` and
    `Data.Functor.Compose`
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Thu Dec 10 2020 psimons@suse.com
- Update base-orphans to version 0.8.4.
  [#]# Changes in 0.8.4 [2020.12.09]
  - Backport the `Ord` instances for `TyCon` and `TypeRep` to be available on
    GHC 7.0.
* Tue Oct  6 2020 psimons@suse.com
- Update base-orphans to version 0.8.3.
  [#]# Changes in 0.8.3 [2020.09.30]
  - Backport new instances from GHC 9.0/`base-4.15`
  * `MonadFix` and `MonadZip` instances for `Complex`
  * `Ix` instances for tuples of size 6 through 15
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Tue Jan 28 2020 psimons@suse.com
- Update base-orphans to version 0.8.2.
  [#]# Changes in 0.8.2 [2020.01.27]
  - Backport new instances from GHC 8.10/`base-4.14`
  * `Bits`, `Bounded`, `Enum`, `FiniteBits`, `Floating`, `Fractional`,
    `Integral`, `Ix`, `Real`, `RealFrac`, `RealFloat` and `Storable` instances
    for `Data.Ord.Down`
  * `Functor`, `Applicative`, `Monad`, `Alternative`, and `MonadPlus` instances
    for `Kleisli`
  * `Functor`, `Applicative`, and `Monad` instances for
    `(,,) a b` and `(,,,) a b c`
  * `Data` instances for `WrappedArrow` and `WrappedMonad`
  * `Data` and `IsList` instances for `ZipList`
  * `TestEquality` instance for `Compose`
  - Backport the `Typeable (() :: Constraint)` instance to be available on
    GHC 7.8.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Mar 26 2019 psimons@suse.com
- Update base-orphans to version 0.8.1.
  [#]# Changes in 0.8.1 [2019.03.25]
  - Ensure that the test suite passes non-negative numbers to `Bits` methods
    that require them, such as `bit`, `setBit`, `clearBit`, `complementBit`,
    and `testBit`.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update base-orphans to version 0.8.
  [#]# Changes in 0.8 [2018.07.02]
  - Backported new instance from GHC 8.6/`base-4.12`
  * Data types in `GHC.Generics`:
  - `Applicative` instance for `K1`
  - `Semigroup` instances for `U1`, `Par1`, `Rec1`, `K1`, `M1`, `(:*:)`,     `(:.:)`, and `V1`
  - `Monoid`    instances for `U1`, `Par1`, `Rec1`, `K1`, `M1`, `(:*:)`, and `(:.:)`
  * `Foldable` and `Traversable` instances for `Data.Monoid.Alt`
  * `MonadFix`, `MonadZip`, `Data`, `Foldable`, `Traversable`, `Eq1`, `Ord1`,
    `Read1`, and `Show1` instances for `Data.Ord.Down`
* Mon May 14 2018 psimons@suse.com
- Update base-orphans to version 0.7.
  * `Alternative` instance for `ZipList`
  * `Data` instance for `IntPtr` and `WordPtr`
  * `Num`, `Functor`, `Applicative`, `Monad`, `Semigroup`, and `Monoid`
    instances for `Data.Ord.Down`
  * `MonadFail`, `Semigroup`, and `Monoid` instances for strict `ST`
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.6.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.5.4 revision 0 with cabal2obs.
* Tue Apr 12 2016 mimi.vx@gmail.com
- update to 0.5.4
  * Backported Bits, FiniteBits, Floating, Fractional, Integral, IsString, Num, Real,
    RealFloat, and RealFrac instances for Identity and Const
* Tue Mar  8 2016 mimi.vx@gmail.com
- update to 0.5.3
  * Backported Alternative, MonadPlus and MonadZip instances for U1 and Proxy, and
    made the Functor, Foldable, Traversable, Alternative, and Monad instances for
    U1 lazier to correspond with base-4.9
* Sun Feb 28 2016 mimi.vx@gmail.com
- update to 0.5.2
  * Backported Enum, Bounded, Ix, Functor, Applicative, Monad, MonadFix, MonadPlus,
    MonadZip, Foldable, Traversable, and Data instances for datatypes
    in the GHC.Generics module (introduced in base-4.9)
* Tue Feb  2 2016 mimi.vx@gmail.com
- update to 0.5.1
  * The Storable instances for Complex and Ratio are now exactly
    as lazy as their counterparts in base
* Wed Jan 20 2016 mimi.vx@gmail.com
- update to 0.5.0
  * Backported instances introduced in GHC 8.0/base-4.9
* Thu Dec 17 2015 mimi.vx@gmail.com
- update to 0.4.5
  * Import Control.Monad.Instances
  * Fix build on GHC HEAD (again)
* Sun Aug 16 2015 mimi.vx@gmail.com
- update to 0.4.4
  * Fix build on GHC HEAD
* Thu Aug 13 2015 mimi.vx@gmail.com
- update to 0.4.3
  * Fix build on OSes where HTYPE_DEV_T = Int32
* Thu Aug  6 2015 mimi.vx@gmail.com
- initial commit
